@@ -799,7 +799,7 @@ class Sf:
         else:
             return account_page_layouts_bulk
 
-    async def retrieve_user_profile_record_type_default(self, username: str, objects: list[str]):
+    async def retrieve_user_profile_record_type_details(self, username: str, objects: list[str]):
         
         profile_metadata = pd.DataFrame(zeep.helpers.serialize_object(self.metadata_list("Profile")))
         profile_metadata = profile_metadata[['id', 'fullName']].copy()
@@ -849,6 +849,9 @@ class Sf:
             object_rt_visibility_with_master['visible'].fillna(False, inplace=True)
             if not object_rt_visibility_with_master['visible'].any():
                 object_rt_visibility_with_master.loc[object_rt_visibility_with_master['developerName'] == 'Master', 'visible'] = True
+            if not object_rt_visibility_with_master['default'].any():
+                object_rt_visibility_with_master.loc[object_rt_visibility_with_master['developerName'] == 'Master', 'default'] = True
+                
             visible_object_rt = object_rt_visibility_with_master[object_rt_visibility_with_master['visible'] == True].drop(['defaultRecordTypeMapping'], axis=1)
             results[object] = visible_object_rt
         
